@@ -17,7 +17,7 @@
 import os, pickle, threading
 from os import path
 import random
-from calculate.lib.utils.files import listDirectory
+from calculate.lib.utils.files import listDirectory, readFile, readLinesFile
 from calculate.lib.utils.tools import ignore
 import socket
 
@@ -34,6 +34,14 @@ class ProcessMode:
     CoreDaemon = "core"
     LocalCall = "local"
 
+def get_symlink_commands():
+    """
+    Получить список команд утилит
+    """
+    symlinks = "/var/lib/calculate/calculate-core/conf/symlinks"
+    for line in readLinesFile(symlinks):
+        yield line.strip()
+    yield "/usr/sbin/cl-core"
 
 def search_worked_process(method_name, clVars,
                           statuses=(ProcessStatus.Worked,)):
@@ -51,8 +59,12 @@ def search_worked_process(method_name, clVars,
                 status = pickle.load(open(pidfile))
                 if ((method_name is None or status['name'] == method_name) and
                             status['status'] in statuses):
-                    if path.exists(path.join("/proc", str(status['os_pid']))):
-                        yield status['os_pid']
+                    pid_path = path.join("/proc", str(status['os_pid']))
+                    if path.exists(pid_path):
+                        cmdline = readFile(path.join(pid_path, "cmdline"))
+                        if cmdline and any(x in cmdline
+                                           for x in get_symlink_commands()):
+                            yield status['os_pid']
             except (socket.error, ValueError, KeyError, EOFError, OSError):
                 pass
 
@@ -227,4 +239,4 @@ class CoreWsdl():
             except OSError, e:
                 print 'No such process %d' %meth.pid, e
                 return 1
-        return 0
+        return 0
\ No newline at end of file
